Description: Mi van a Földön túl? Honnan jöttünk? Miből lettünk? Mi az élet titka? Valóban határtalanok a képességeink és hatalmunk? Kik vagyunk? Ez az izgalmas sorozat bemutatja, hogyan alakította a tudomány az életünket.

# A tudomány története / Mi van rajtunk kívül?

The Story of Science / What's out there?
angol dokumentumfilm sorozat, I / 1. rész, 51 perc

- Értesítőt kérek
- Bakancslista
- Megosztom

## Értékelés:

12 szavazatból
Szerinted?

2 hozzászólás

+ 1 kép
+ 3 kép

## Értékelés:

12 szavazatból
Szerinted?

2 hozzászólás
Vetítések:
4:15, vasárnap (december 08.)
Spektrum
Mi van a Földön túl? Honnan jöttünk? Miből lettünk? Mi az élet titka? Valóban határtalanok a képességeink és hatalmunk? Kik vagyunk? Ez az izgalmas sorozat bemutatja, hogyan alakította a tudomány az életünket.
Teljes leírás

### Évadok:

- 1

## Stáblista

### Alkotók

- szereplő: Michael J. Mosley
- rendező: Nicola Cook Giles Harrison Peter Oxley Nat Sharman Jeremy Turner Nigel Walk
- zeneszerző: Ty Unwin
- producer: Aidan Laverty
- vágó: Ian Arwas

Stáblista mutatása
Játszási időpontok Hozzászólások (2)

## Játszási időpontok

december 9. - hétfő

- 04:15 Spektrum I / 2. rész

december 15. - vasárnap

- 04:15 Spektrum I / 3. rész

december 16. - hétfő

- 04:15 Spektrum I / 4. rész

december 22. - vasárnap

- 04:15 Spektrum I / 5. rész

Spektrum
december 9. - hétfő I / 5. rész

- 04:15

december 15. - vasárnap I / 5. rész

- 04:15

december 16. - hétfő I / 5. rész

- 04:15

december 22. - vasárnap I / 5. rész

- 04:15

Teljes lista
Szerkeszd te is a Port.hu-t!

#### Ha hiányosságot találsz, vagy valamihez van valamilyen érdekes hozzászólásod, írd meg nekünk!

Küldés

Figyelem: A beküldött észrevételeket a szerkesztőink értékelik, csak azok a javasolt változtatások valósulhatnak meg, amik jóváhagyást kapnak. Kérjük, forrásmegjelöléssel támaszd alá a leírtakat!

## Hozzászólások

Spoiler
Offtopik
Szerinted?

TerMiki 2013 ápr. 11. - 09:40:32 Előzmény GORiARTY
Remek kis sorozat. Egyelõre HDD-re rögzítem. Most azzal vívok, hogy a 2. rész végre hibamentesen lejöjjön. Na, nem nagy a hiba, egy "akadás" van benne a maga 2-3 másodpercével - de engem az õrületbe kerget.
Skytec HD 110 IR mûholdvevõvel veszem fel, de nem HD minõségben, hanem csak MPEG2. Ezt azért írtam le, mert ez a b..i beltéri nem szabványos TS fájlokat rögzít - védve tõlem a saját jogaimat - és csak a beltéri játssza le. Azzal meg digitális-analóg(kábel)-digitális másolási cirkusszal tud DVD-re kerülni. Ha ismeri ezt a beltérit és van módszere a TS fájlként való kezelésére, akkor az nem esik át minõségromláson. Ha nem, akkor megegyezünk DVD-n.
km.szecska@freemail.hu
Válasz
10/10
GORiARTY 2013 ápr. 04. - 14:12:24 10/10
Szia Kedves Olvasó!
Amennyiben lehetõséged van felvenni ezt a sorozatot, kérlek, jelezd itt a fórumban, nagyon hálás lennék érte.
Sajnos több okból sem tudom megoldani és se DVD-n se sehogy nem szokták kiadni az ilyeneket, engem viszont nagyon érdekelne.
Köszönöm szépen
G
Válasz
Vetítések:
4:15, vasárnap (december 08.)
Spektrum

# Címlapon

tv 2025-ben visszatér a Csillag születik! az RTL-en
tv Megvan az X-Faktor 2024 győztese
tv Ezeket a filmeket ajánljuk vasárnapra
magazin Vasárnapi programajánló
tv Családi filmek vasárnapra

# Legolvasottabb cikkeink

mozi 8 elképesztő időutazós sci-fi, amiről talán nem is hallottál
mozi 60 éves Marisa Tomei, akinek még mi sem adtuk volna oda azt a bizonyos Oscart, pedig imádjuk
mozi Ez a 4 film elérte azt, hogy párkapcsolatokat tegyen tönkre
magazin Unod a sablonokat? Íme 5 tökéletesen eredeti film
stream A svédek hozták el a Netflix idei legjobb sorozatát
mozi Ez az 5 legbénább filmes fordulat

# PORT.hu a Facebookon

##### Figyelmeztetés

Az értesítések jelenleg le vannak tiltva! Amennyiben szeretnél cikkajánlókat kapni, kérlek, hogy a böngésző Beállítások / Értesítések menüpontja alatt állítsd be az értesítések engedélyezését!

## Bejelentkezés

Jelentkezz be!

Belépek Facebookkal
VAGY
Hibás email cím vagy jelszó!
Elfelejtettem a jelszavam
Maradjak belépve
Regisztrálok»